==> gbsite-1.0.0.tar.gz: gbsite/htdocs/admin/showpage.php <==
<?
    require_once("config.php");

    $conn  = pg_pconnect("host=$DBHOST port=$DBPORT user=$DBUSER dbname=$DBNAME password=$DBPASS");

    $query = "select * ".
             "  from page_info ".
             " where http_host = '$w_siteid' ".
             "   and web_page  = '$pageid' ";

    $res   = pg_exec($conn, $query);
    
    $page = pg_fetch_object($res,0);


 ?>
<a href="listsites.php">Site List</a> |
<a href="showsite.php?w_siteid=<?= $w_siteid ?>">Back to Site</a> |
<a href="showpage.php?w_siteid=<?= $w_siteid ?>&pageid=<?= $pageid ?>">Refresh</a><p>
<form method=post action="updatepage.php">
<input type=hidden name="action" value="update">
<input type=hidden name="w_siteid" value="<?= $w_siteid ?>">
<input type=hidden name="pageid" value="<?= $pageid ?>">
<table border=1>
<tr><td>Page Name:</td>
    <td><?= $page->web_page ?></td></tr>
<tr><td>Page Title:</td>
    <td><input type=text name="page_title" value="<?= $page->page_title ?>" size=20 maxlength=128></td></tr>
<tr><td>Page template:</td>
    <td><input type=text name="page_template" value="<?= $page->page_template ?>" size=40 maxlength=128></td></tr>
<tr><td>Page Header:</td>
    <td><input type=text name="page_header" value="<?= $page->page_header ?>"></td></tr>
<tr><td>Meta Description:</td>
    <td><textarea rows=5 cols=40 name="meta_description"><?= $page->meta_description ?></textarea></td></tr>
<tr><td>Meta keyword:</td>
    <td><textarea rows=5 cols=40 name="meta_keyword"><?= $page->meta_keyword ?></textarea></td></tr>
<tr><td>Group:</td>
    <td><select name="group_id">
        <option value="">Top Level</option> 
<?
    $query = "select group_id from group_info where http_host = '$w_siteid' order by order_number";
    $res   = pg_exec($conn,$query);
    $r = 0;
    while($row = @pg_fetch_object($res,$r++)) {
        $selected = ($page->group_id == $row->group_id?" SELECTED":"");
        echo "        <option value=\"" . $row->group_id . "\"$selected>" . $row->group_id . "</option>\n";
    }
 ?>
        </select></td></tr>
<tr><td>Link URL:</td>
    <td><input type=text name="page_url" value="<?= $page->page_url ?>"></td></tr>
<tr><td>Link Name:</td>
    <td><input type=text name="link_name" value="<?= $page->link_name ?>"></td></tr>
<tr><td>Order Number:</td>
    <td><input type=text name="order_number" value="<?= $page->order_number ?>" size=5></td></tr>
<tr><td>Active?</td>
    <td><input type=radio name=active value="true"<?= ($page->active=="t"?" CHECKED":"") ?>> True<br>
        <input type=radio name=active value="false"<?= ($page->active=="f"?" CHECKED":"") ?>> False<br></td></tr>
<tr><td>Last Updated:</td>
    <td><?= $page->last_updated ?></td></tr>
<tr><td align=center colspan=2>
       <input type=submit value="Update">
       <input type=reset></td></tr>
</table>
</form>


<form method=post action="updatepage.php">
<input type=hidden name="action" value="delete">
<input type=hidden name="w_siteid" value="<?= $w_siteid ?>">
<input type=hidden name="pageid" value="<?= $pageid ?>">
<input type=submit value="Delete">
</form>

==> gbsite-1.1.1.tar.gz: gbsite/htdocs/admin/showpage.php <==
<?
    require_once("config.php");

    $conn  = pg_pconnect("host=$DBHOST port=$DBPORT user=$DBUSER dbname=$DBNAME password=$DBPASS");

    $query = "select * ".
             "  from page_info ".
             " where http_host = '$w_siteid' ".
             "   and web_page  = '$pageid' ";

    $res   = pg_exec($conn, $query);
    
    $page = pg_fetch_object($res,0);

    $field_num = pg_fieldnum($res,"group_id");
    if(pg_fieldisnull($res,0,$field_num))
        $page->group_id = "\\N";

 ?>
<a href="listsites.php">Site List</a> |
<a href="showsite.php?w_siteid=<?= $w_siteid ?>">Back to Site</a> |
<a href="showpage.php?w_siteid=<?= $w_siteid ?>&pageid=<?= $pageid ?>">Refresh</a><p>
<form method=post action="updatepage.php">
<input type=hidden name="action" value="update">
<input type=hidden name="w_siteid" value="<?= $w_siteid ?>">
<input type=hidden name="pageid" value="<?= $pageid ?>">
<table border=1>
<tr><td>Page Name:</td>
    <td><?= $page->web_page ?></td></tr>
<tr><td>Page Title:</td>
    <td><input type=text name="page_title" value="<?= $page->page_title ?>" size=20 maxlength=128></td></tr>
<tr><td>Page template:</td>
    <td><input type=text name="page_template" value="<?= $page->page_template ?>" size=40 maxlength=128></td></tr>
<tr><td>Page Header:</td>
    <td><input type=text name="page_header" value="<?= $page->page_header ?>"></td></tr>
<tr><td>Meta Description:</td>
    <td><textarea rows=5 cols=40 name="meta_description"><?= $page->meta_description ?></textarea></td></tr>
<tr><td>Meta keyword:</td>
    <td><textarea rows=5 cols=40 name="meta_keyword"><?= $page->meta_keyword ?></textarea></td></tr>
<tr><td>Group:</td>
    <td><select name="group_id">
        <option value="\N" <?= ($page->group_id == "\\N"? "SELECTED":"") ?>>Unassigned</option>
        <option value="" <?= ($page->group_id == "" ? "SELECTED":"") ?>>Top Level</option> 
<?
    $query = "select group_id from group_info where http_host = '$w_siteid' order by order_number";
    $res   = pg_exec($conn,$query);
    $r = 0;
    while($row = @pg_fetch_object($res,$r++)) {
        $selected = ($page->group_id == $row->group_id?" SELECTED":"");
        echo "        <option value=\"" . $row->group_id . "\"$selected>" . $row->group_id . "</option>\n";
    }
 ?>
        </select></td></tr>
<tr><td>Link URL:</td>
    <td><input type=text name="page_url" value="<?= $page->page_url ?>"></td></tr>
<tr><td>Link Name:</td>
    <td><input type=text name="link_name" value="<?= $page->link_name ?>"></td></tr>
<tr><td>Order Number:</td>
    <td><input type=text name="order_number" value="<?= $page->order_number ?>" size=5></td></tr>
<tr><td>Use Master:</td>
    <td><input type=radio name=use_master value="true"<?= ($page->use_master=="t"?" CHECKED":"") ?>> True<br>
        <input type=radio name=use_master value="false"<?= ($page->use_master=="f"?" CHECKED":"") ?>> False<br></td></tr>
<tr><td>Active?</td>
    <td><input type=radio name=active value="true"<?= ($page->active=="t"?" CHECKED":"") ?>> True<br>
        <input type=radio name=active value="false"<?= ($page->active=="f"?" CHECKED":"") ?>> False<br></td></tr>
<tr><td>Last Updated:</td>
    <td><?= $page->last_updated ?></td></tr>
<tr><td align=center colspan=2>
       <input type=submit value="Update">
       <input type=reset></td></tr>
</table>
</form>


<form method=post action="updatepage.php">
<input type=hidden name="action" value="delete">
<input type=hidden name="w_siteid" value="<?= $w_siteid ?>">
<input type=hidden name="pageid" value="<?= $pageid ?>">
<input type=submit value="Delete">
</form>
